==> 4.4.3.tar.gz: terraform-provider-decort/samples/cloudapi/data_vins_list/main.tf <==
/*
Пример использования
Получение списка vins
*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
}
*/

provider "decort" {
  authenticator = "oauth2"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_vins_list" "vl" {
  #фильтр по id vins
  #опциональный параметр
  #тип - число
  #by_id = 100
 
  #фильтр по имени vins
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для получения списка балансировщиков нагрузки
  #опциональный параметр 
  #тип - число
  #account_id = 11111

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - число
  #rg_id = 100

  #фильтр по IP внешней сети
  #опциональный параметр
  #тип - строка
  #ext_ip = "test"

  #включение удаленных vins в результат
  #опциональный параметр
  #тип - будев тип
  #если не задан - выводятся все неудаленные данные
  #include_deleted = true

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 1

}

output "test" {
  value = data.decort_vins_list.vl
}

==> 4.5.0.tar.gz: terraform-provider-decort/samples/cloudapi/data_vins_list/main.tf <==
/*
Пример использования
Получение списка vins
*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_vins_list" "vl" {
  #фильтр по id vins
  #опциональный параметр
  #тип - число
  #by_id = 100
 
  #фильтр по имени vins
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для получения списка балансировщиков нагрузки
  #опциональный параметр 
  #тип - число
  #account_id = 11111

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - число
  #rg_id = 100

  #фильтр по IP внешней сети
  #опциональный параметр
  #тип - строка
  #ext_ip = "test"

  #включение удаленных vins в результат
  #опциональный параметр
  #тип - будев тип
  #если не задан - выводятся все неудаленные данные
  #include_deleted = true

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 1

}

output "test" {
  value = data.decort_vins_list.vl
}
